@@ -91,7 +91,7 @@ class DropboxClient(object):
             A dictionary containing account information.
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#account-info
+            https://www.dropbox.com/developers/reference/api#account-info
         """
         url, params, headers = self.request("/account/info", method='GET')
 
@@ -125,7 +125,7 @@ class DropboxClient(object):
             A dictionary containing the metadata of the newly uploaded file.
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#files-put
+            https://www.dropbox.com/developers/reference/api#files-put
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -189,7 +189,7 @@ class DropboxClient(object):
         Returns:
             - An httplib.HTTPResponse that is the result of the request.
             - A dictionary containing the metadata of the file (see
-              https://www.dropbox.com/developers/docs#metadata for details).
+              https://www.dropbox.com/developers/reference/api#metadata for details).
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -217,6 +217,103 @@ class DropboxClient(object):
         if not metadata: raise ErrorResponse(dropbox_raw_response)
         return metadata
 
+    def delta(self, cursor=None):
+        """A way of letting you keep up with changes to files and folders in a
+        user's Dropbox.  You can periodically call delta() to get a list of "delta
+        entries", which are instructions on how to update your local state to
+        match the server's state.
+
+        Arguments:
+          - ``cursor``: On the first call, omit this argument (or pass in ``None``).  On
+            subsequent calls, pass in the ``cursor`` string returned by the previous
+            call.
+
+        Returns: A dict with three fields.
+          - ``entries``: A list of "delta entries" (described below)
+          - ``reset``: If ``True``, you should your local state to be an empty folder
+            before processing the list of delta entries.  This is only ``True`` only
+            in rare situations.
+          - ``cursor``: A string that is used to keep track of your current state.
+            On the next call to delta(), pass in this value to return entries
+            that were recorded since the cursor was returned.
+          - ``has_more``: If ``True``, then there are more entries available; you can
+            call delta() again immediately to retrieve those entries.  If ``False``,
+            then wait at least 5 minutes (preferably longer) before checking again.
+
+        Delta Entries: Each entry is a 2-item list of one of following forms:
+          - [*path*, *metadata*]: Indicates that there is a file/folder at the given
+            path.  You should add the entry to your local path.  (The *metadata*
+            value is the same as what would be returned by the ``metadata()`` call.)
+              - If the new entry includes parent folders that don't yet exist in your
+                local state, create those parent folders in your local state.  You
+                will eventually get entries for those parent folders.
+              - If the new entry is a file, replace whatever your local state has at
+                *path* with the new entry.
+              - If the new entry is a folder, check what your local state has at
+                *path*.  If it's a file, replace it with the new entry.  If it's a
+                folder, apply the new *metadata* to the folder, but do not modify
+                the folder's children.
+          - [*path*, ``nil``]: Indicates that there is no file/folder at the *path* on
+            Dropbox.  To update your local state to match, delete whatever is at *path*,
+            including any children (you will sometimes also get "delete" delta entries
+            for the children, but this is not guaranteed).  If your local state doesn't
+            have anything at *path*, ignore this entry.
+
+        Remember: Dropbox treats file names in a case-insensitive but case-preserving
+        way.  To facilitate this, the *path* strings above are lower-cased versions of
+        the actual path.  The *metadata* dicts have the original, case-preserved path.
+        """
+        path = "/delta"
+
+        params = {}
+        if cursor is not None:
+            params['cursor'] = cursor
+
+        url, params, headers = self.request(path, params)
+
+        return RESTClient.POST(url, params, headers)
+
+
+    def create_copy_ref(self, from_path):
+        """Creates and returns a copy ref for a specific file.  The copy ref can be
+        used to instantly copy that file to the Dropbox of another account.
+
+        Args:
+         - path: The path to the file for a copy ref to be created on.
+
+        Returns:
+            A dictionary that looks like the following example:
+
+            ``{"expires":"Fri, 31 Jan 2042 21:01:05 +0000", "copy_ref":"z1X6ATl6aWtzOGq0c3g5Ng"}``
+
+        """
+        path = "/copy_ref/%s%s" % (self.session.root, format_path(from_path))
+
+        url, params, headers = self.request(path, {})
+
+        return RESTClient.GET(url, headers)
+
+    def add_copy_ref(self, copy_ref, to_path):
+        """Adds the file referenced by the copy ref to the specified path
+
+        Args:
+         - copy_ref: A copy ref string that was returned from a create_copy_ref call.
+           The copy_ref can be created from any other Dropbox account, or from the same account.
+         - path: The path to where the file will be created.
+
+        Returns:
+            A dictionary containing the metadata of the new copy of the file.
+         """
+        path = "/fileops/copy"
+
+        params = {'from_copy_ref': copy_ref,
+                  'to_path': format_path(to_path),
+                  'root': self.session.root}
+
+        url, params, headers = self.request(path, params)
+
+        return RESTClient.POST(url, params, headers)
+
     def file_copy(self, from_path, to_path):
         """Copy a file or folder to a new location.
 
@@ -233,7 +330,7 @@ class DropboxClient(object):
             A dictionary containing the metadata of the new copy of the file or folder.
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#fileops-copy
+            https://www.dropbox.com/developers/reference/api#fileops-copy
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of:
@@ -262,7 +359,7 @@ class DropboxClient(object):
             A dictionary containing the metadata of the newly created folder.
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#fileops-create-folder
+            https://www.dropbox.com/developers/reference/api#fileops-create-folder
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -286,7 +383,7 @@ class DropboxClient(object):
             A dictionary containing the metadata of the just deleted file.
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#fileops-delete
+            https://www.dropbox.com/developers/reference/api#fileops-delete
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -316,7 +413,7 @@ class DropboxClient(object):
             A dictionary containing the metadata of the new copy of the file or folder.
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#fileops-move
+            https://www.dropbox.com/developers/reference/api#fileops-move
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -357,7 +454,7 @@ class DropboxClient(object):
             (and contained files if appropriate).
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#metadata
+            https://www.dropbox.com/developers/reference/api#metadata
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -397,7 +494,7 @@ class DropboxClient(object):
                At this time, 'small', 'medium', and 'large' are
                officially supported sizes (32x32, 64x64, and 128x128
                respectively), though others may be available. Check
-               https://www.dropbox.com/developers/docs#thumbnails for
+               https://www.dropbox.com/developers/reference/api#thumbnails for
                more details.
 
         Returns:
@@ -414,7 +511,7 @@ class DropboxClient(object):
 
         path = "/thumbnails/%s%s" % (self.session.root, format_path(from_path))
 
-        url, params, headers = self.request(path, {'size': size}, method='GET', content_server=True)
+        url, params, headers = self.request(path, {'size': size, 'format': format}, method='GET', content_server=True)
         return RESTClient.request("GET", url, headers=headers, raw_response=True)
 
     def thumbnail_and_metadata(self, from_path, size='large', format='JPEG'):
@@ -431,7 +528,7 @@ class DropboxClient(object):
         Returns:
             - An httplib.HTTPResponse that is the result of the request.
             - A dictionary containing the metadata of the file whose thumbnail
-              was downloaded (see https://www.dropbox.com/developers/docs#metadata
+              was downloaded (see https://www.dropbox.com/developers/reference/api#metadata
               for details).
 
         Raises:
@@ -464,7 +561,7 @@ class DropboxClient(object):
             A list of the metadata of all matching files (up to
             file_limit entries).  For a detailed description of what
             this call returns, visit:
-            https://www.dropbox.com/developers/docs#search
+            https://www.dropbox.com/developers/reference/api#search
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -481,6 +578,9 @@ class DropboxClient(object):
 
         url, params, headers = self.request(path, params)
 
+        print "--- URL: %r" % url
+        print "       : %r" % params
+
         return RESTClient.POST(url, params, headers)
 
     def revisions(self, path, rev_limit=1000):
@@ -496,7 +596,7 @@ class DropboxClient(object):
             A list of the metadata of all matching files (up to rev_limit entries).
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#revisions
+            https://www.dropbox.com/developers/reference/api#revisions
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -525,7 +625,7 @@ class DropboxClient(object):
             A dictionary containing the metadata of the newly restored file.
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#restore
+            https://www.dropbox.com/developers/reference/api#restore
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -561,7 +661,7 @@ class DropboxClient(object):
             ``{'url': 'https://dl.dropbox.com/0/view/wvxv1fw6on24qw7/file.mov', 'expires': 'Thu, 16 Sep 2011 01:01:25 +0000'}``
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#media
+            https://www.dropbox.com/developers/reference/api#media
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
@@ -592,7 +692,7 @@ class DropboxClient(object):
             ``{'url': 'http://www.dropbox.com/s/m/a2mbDa2', 'expires': 'Thu, 16 Sep 2011 01:01:25 +0000'}``
 
             For a detailed description of what this call returns, visit:
-            https://www.dropbox.com/developers/docs#share
+            https://www.dropbox.com/developers/reference/api#shares
 
         Raises:
             A dropbox.rest.ErrorResponse with an HTTP status of
